*****
Tests
*****
Ringo come two types of tests:

 1. Functional and Unit tests and
 2. Behaviour driven tests using the `Behave <http://www.behave.org>`_ framework. All tests are located are under "ringo/tests" directory.

Start the tests by invoking the following command::

        invoke tests

This will create new test database calls the tests and make some statistics on
the code coverage.

